WriteEncoder

Struct WriteEncoder 

pub struct WriteEncoder<'a, T: Algorithm, D: Write> {
    pub destination: D,
    /* private fields */
}

Fields

destination: D

Implementations

Source

impl<'a, T: Algorithm, D: Write> WriteEncoder<'a, T, D>

pub fn new(algorithm: &'a T, destination: D, level: CompressionLevel) -> Self

pub fn queue(&mut self, data: &[u8])

Sends data to a buffer

pub fn write(&mut self) -> Result<()>

Compresses all data within the buffer and writes it to disk

pub fn finish(self) -> Result<D, CompressionError>

Finalises the data that is being written to disk and writes any tail data. Returns to File object where the compressed data is now stored